summaryrefslogtreecommitdiffstats
path: root/ppapi/proxy/plugin_dispatcher.h
diff options
context:
space:
mode:
Diffstat (limited to 'ppapi/proxy/plugin_dispatcher.h')
-rw-r--r--ppapi/proxy/plugin_dispatcher.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/ppapi/proxy/plugin_dispatcher.h b/ppapi/proxy/plugin_dispatcher.h
index dbc13d2..efa0d70 100644
--- a/ppapi/proxy/plugin_dispatcher.h
+++ b/ppapi/proxy/plugin_dispatcher.h
@@ -35,7 +35,7 @@ class PluginDispatcher : public Dispatcher {
// will be automatically called when requested by the renderer side. The
// module ID will be set upon receipt of the InitializeModule message.
//
// You must call Dispatcher::InitWithChannel after the constructor.
PluginDispatcher(base::ProcessHandle remote_process_handle,
GetInterfaceFunc get_interface);
virtual ~PluginDispatcher();
@@ -48,10 +48,14 @@ class PluginDispatcher : public Dispatcher {
static const void* GetInterfaceFromDispatcher(const char* interface);
+ // You must call this function before anything else. Returns true on success.
+ // The delegate pointer must outlive this class, ownership is not
+ // transferred.
+ virtual bool InitPluginWithChannel(Dispatcher::Delegate* delegate,
+ const IPC::ChannelHandle& channel_handle,
+ bool is_client);
+
// Dispatcher overrides.
- virtual bool InitWithChannel(Delegate* delegate,
- const IPC::ChannelHandle& channel_handle,
- bool is_client);
virtual bool IsPlugin() const;
virtual bool Send(IPC::Message* msg);
@@ -68,10 +72,6 @@ class PluginDispatcher : public Dispatcher {
// correspond to a known instance.
InstanceData* GetInstanceData(PP_Instance instance);
-#if defined(OS_POSIX)
- int GetRendererFD();
-#endif
-
private:
friend class PluginDispatcherTest;
@@ -35,7 +35,7 @@ class PluginDispatcher : public Dispatcher {
// module ID will be set upon receipt of the InitializeModule message.
//
- // You must call Dispatcher::InitWithChannel after the constructor.
+ // You must call InitPluginWithChannel after the constructor.
PluginDispatcher(base::ProcessHandle remote_process_handle,
GetInterfaceFunc get_interface);